@@ -1,12 +1,17 @@
 
 package String::CRC32;
 
+use strict;
+use warnings;
+
 require Exporter;
 require DynaLoader;
 
+use vars qw/ @ISA $VERSION @EXPORT_OK @EXPORT /;
+
 @ISA = qw(Exporter DynaLoader);
 
-$VERSION = 1.4;
+$VERSION = 1.5_01;
 
 # Items to export into callers namespace by default
 @EXPORT = qw(crc32);
